scoretools.PerformerInventory
=============================

.. abjad-lineage:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory

.. autoclass:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.append
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.count
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.extend
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.index
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.insert
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.pop
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.remove
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.reverse
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__add__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__contains__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__delslice__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__eq__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ge__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__getslice__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__gt__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iadd__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__imul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__iter__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__le__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__len__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__lt__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__mul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__ne__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__repr__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__reversed__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__rmul__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setitem__
   :noindex:

.. automethod:: abjad.tools.scoretools.PerformerInventory.PerformerInventory.PerformerInventory.__setslice__
   :noindex:
